Tools to scaffold, standardize, validate, transform, and package salmon datasets using the Salmon Data Package conventions plus shared and DFO-specific salmon vocabularies.
Author
Maintainer: Brett Johnson brettthomasjohnson@gmail.com
Authors:
Brett Johnson brettthomasjohnson@gmail.com