Suggest Darwin Core Data Package mappings for dictionary columns
Source:R/dwc-dp-helpers.R
suggest_dwc_mappings.RdUses DwC Conceptual Model + DwC-DP table schemas (cached locally) to suggest likely table/field mappings for column dictionary entries, and returns the associated Darwin Core property IRIs for review.
Value
The dictionary tibble with a dwc_mappings attribute containing
suggestions (columns: column_name, table_id, field_name, field_label,
term_iri, match_score, match_basis).
Examples
dict <- infer_dictionary(mtcars)
dict <- suggest_dwc_mappings(dict)
#> No DwC-DP mapping suggestions found.
head(attr(dict, "dwc_mappings"))
#> # A tibble: 0 × 0